****************
Glossary
****************

.. glossary::

    PDF
        Probability density function. Describes the probability of a random variable to take a given value.

    MPI
        Message Passing Interface. A method of communicating across nodes on multinode systems. `Standard <http://www.mcs.anl.gov/research/projects/mpi/>`_ `OpenMPI implementation <http://www.open-mpi.org/>`_

    CSV
        Comma separated values. A simple method for storing (tabular) data by separating values using commas.

    walltime
        The length of time a job runs for on a cluster.

    Monte Carlo method
        A method of determining the distribution of an unknown entity using random sampling to obtain numerical results.